@@ -6,12 +6,12 @@ use utf8; # Files and dictionaries might use utf8
 use Encode;
 
 use Carp;
-use File::Slurp::Tiny 'read_file';
+use Path::Tiny;
 use Text::Hunspell;
 use Test::Text::Sentence qw(split_sentences);
 use v5.22;
 
-use version; our $VERSION = qv('0.6.4'); # Works with UTF8 and includes Text::Sentence
+use version; our $VERSION = qv('0.6.5'); # Works with UTF8 and includes Text::Sentence
 
 use parent 'Test::Builder::Module'; # Included in Test::Simple
 
@@ -31,7 +31,7 @@ sub new {
   my $language = shift || "en_US"; # Defaults to English
   my @files = @_ ; # Use all appropriate files in dir by default
   if (!@files ) {
-    @files = glob("$dir/*.md $dir/*.tex $dir/*.txt $dir/*.markdown)");
+    @files = glob("$dir/*.md $dir/*.tex $dir/*.txt $dir/*.markdown $dir/*.Rmd $dir/*.Rmarkdown)");
   } else {
     @files = map( "$dir/$_", @files );
   }
@@ -68,7 +68,7 @@ sub check {
   my %vocabulary;
   my @sentences;
   for my $f ( @{$self->files}) {
-    my $file_content= read_file($f, binmode => ':utf8');
+    my $file_content= path($f)->slurp_utf8;
     if ( $f =~ /(\.md|\.markdown)/ ) {
       $file_content = _strip_urls( $file_content);
       $file_content = _strip_code( $file_content);
